@@ -107,7 +107,6 @@ class EquivariantAttention(nn.Module):
         m_dim = 16,
         fourier_features = 4,
         norm_rel_coors = False,
-        norm_coor_weights = False,
         num_nearest_neighbors = 0,
         only_sparse_neighbors = False,
         valid_neighbor_radius = float('inf'),
@@ -125,7 +124,7 @@ class EquivariantAttention(nn.Module):
         self.to_out = nn.Linear(attn_inner_dim, dim)
 
         pos_dim = (fourier_features * 2) + 1
-        edge_input_dim = dim_head + edge_dim
+        edge_input_dim = (dim_head * 2) + edge_dim
 
         self.to_pos_emb = nn.Sequential(
             nn.Linear(pos_dim, dim_head * 2),
@@ -271,7 +270,7 @@ class EquivariantAttention(nn.Module):
 
         q = repeat(q, 'b h i d -> b h i n d', n = j)
 
-        edge_input = (q - k) + rel_dist_pos_emb
+        edge_input = torch.cat(((q * k), rel_dist_pos_emb), dim = -1)
 
         if exists(edges):
             if exists(nbhd_indices):
@@ -330,7 +329,6 @@ class EnTransformer(nn.Module):
         only_sparse_neighbors = False,
         valid_neighbor_radius = float('inf'),
         norm_rel_coors = False,
-        norm_coor_weights = False,
         init_eps = 1e-3
     ):
         super().__init__()
@@ -339,7 +337,7 @@ class EnTransformer(nn.Module):
         self.layers = nn.ModuleList([])
         for _ in range(depth):
             self.layers.append(nn.ModuleList([
-                Residual(PreNorm(dim, EquivariantAttention(dim = dim, dim_head = dim_head, heads = heads, m_dim = m_dim, edge_dim = edge_dim, fourier_features = fourier_features, norm_rel_coors = norm_rel_coors,  norm_coor_weights = norm_coor_weights, num_nearest_neighbors = num_nearest_neighbors, only_sparse_neighbors = only_sparse_neighbors, valid_neighbor_radius = valid_neighbor_radius, init_eps = init_eps))),
+                Residual(PreNorm(dim, EquivariantAttention(dim = dim, dim_head = dim_head, heads = heads, m_dim = m_dim, edge_dim = edge_dim, fourier_features = fourier_features, norm_rel_coors = norm_rel_coors,  num_nearest_neighbors = num_nearest_neighbors, only_sparse_neighbors = only_sparse_neighbors, valid_neighbor_radius = valid_neighbor_radius, init_eps = init_eps))),
                 Residual(PreNorm(dim, FeedForward(dim = dim)))
             ]))
 
